# Microsoft Bing
- [Bing](https://bing.com)
- [AGiXT](https://github.com/Josh-XT/AGiXT)

## Disclaimer

We are not responsible if Microsoft bans your account for doing this. This may not be consistent with their rules to use their services in this way. This was developed for experimental purposes and we assume no responsibility for how you use it.

## Quick Start Guide

### Get your Bing Cookies

1. Install the [EditThisCookie extension for Chrome](https://chrome.google.com/webstore/detail/editthiscookie/fngmhnnpilhplaeedifhccceomclgfbg)
2. Go to https://bing.com
3. Open the extension
4. Click the export button (Looks like `[>`), this saves your cookies to clipboard.
5. Paste your cookies into a file `cookies.json` in your `AGiXT` directory

### Update your agent settings
Set `AI_PROVIDER` to `bing`.
